/*
 * Copyright (c) 2018-2019 CERN (home.cern)
 * Author: Tomasz Wlostowski <tomasz.wlostowski@cern.ch>
 *
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */


#ifndef __TRTL_ENDPOINT_H
#define __TRTL_ENDPOINT_H

enum trtl_ep_type {
	TRTL_EP_ETH = 0,
	__TRTL_EP_MAX,
};

#define TRTL_EP_OUT_CONFIG 0
#define TRTL_EP_OUT_MAC_HI 4
#define TRTL_EP_OUT_MAC_LO 8
#define TRTL_EP_OUT_ETHERTYPE 12
#define TRTL_EP_OUT_DST_IP 16
#define TRTL_EP_OUT_SRC_IP 20
#define TRTL_EP_OUT_DST_PORT 24
#define TRTL_EP_OUT_SRC_PORT 28

#define TRTL_EP_FRAME_RAW 0
#define TRTL_EP_FRAME_UDP 1
#define TRTL_EP_FRAME_TLV 2

#define TRTL_EP_FILTER_RAW (1<<2)
#define TRTL_EP_FILTER_UDP (1<<0)
#define TRTL_EP_FILTER_DST_PORT  (1<<5)
#define TRTL_EP_FILTER_ETHERTYPE (1<<5)
#define TRTL_EP_FILTER_DST_MAC   (1<<3)
#define TRTL_EP_FILTER_DST_IP   (1<<6)
#define TRTL_EP_FILTER_TLV0   (1<<7)
#define TRTL_EP_FILTER_TLV1   (1<<8)
#define TRTL_EP_FILTER_TLV2   (1<<9)
#define TRTL_EP_FILTER_TLV3   (1<<10)
#define TRTL_EP_FILTER_ENABLE (1<<31)

#define TRTL_EP_IN_CONFIG 0
#define TRTL_EP_IN_DST_MAC_HI 4
#define TRTL_EP_IN_DST_MAC_LO 8
#define TRTL_EP_IN_ETHERTYPE 12
#define TRTL_EP_IN_DST_IP 16
#define TRTL_EP_IN_DST_PORT 20
#define TRTL_EP_IN_DST_TYPE0 24
#define TRTL_EP_IN_DST_TYPE1 28
#define TRTL_EP_IN_DST_TYPE2 32
#define TRTL_EP_IN_DST_TYPE3 36

struct trtl_ep_eth_address {
  uint32_t type;
  uint32_t filter;
  uint8_t dst_mac[6];
  uint16_t ethertype;
  uint32_t src_ip;
  uint32_t dst_ip;
  uint16_t src_port;
  uint16_t dst_port;
  uint32_t tlvs[4];
};

#endif
